Welcome to listmode’s documentation! — listmode 0.5.0 documentation

# Welcome to listmode’s documentation!

This manual is divided into User manual and function reference.

Contents:

- Introduction
  - What is Listmode
  - How to use Listmode
  - What is data?
  - The flow of data
  - How to start
- Configuration files
  - Detector configuration
  - Plot configuration
- Reference
  - Data
  - Plot
  - Utils
  - Misc
  - Loaders

# Indices and tables

- Index

- Module Index

- Search Page